FaceDatabaseAdapter class abstract
Abstract contract for local face database storage adapters (Memory, JSON, Binary, SQLite).
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> - Clears all stored records from database storage.
-
delete(
String personId) → Future< bool> -
Removes a person record by
personId. -
get(
String personId) → Future< PersonRecord?> -
Retrieves a registered PersonRecord by
personId. -
getAll(
) → Future< List< PersonRecord> > - Returns all registered PersonRecord entries.
-
init(
) → Future< void> - Initializes database storage resources.
-
insert(
PersonRecord record) → Future< void> - Inserts or updates a PersonRecord in database storage.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited