FaceDetector class
Pure Dart multi-scale face detector.
Constructors
- FaceDetector({FaceKitConfig? config})
-
Creates a FaceDetector with optional custom
config.
Properties
- config → FaceKitConfig
-
Active configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
detectFaces(
FaceImage image, {double? threshold, int? maxFaces}) → List< Face> -
Detects faces within the provided
image. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited