FaceKitLogger class
Lightweight zero-dependency logger for FaceKit diagnostics.
Constructors
- FaceKitLogger({FaceKitLogLevel level = FaceKitLogLevel.info, void onLog(String message)?})
-
Creates a FaceKitLogger with specified
leveland optionalonLogcallback.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- level ↔ FaceKitLogLevel
-
Active logging level.
getter/setter pair
- onLog ↔ void Function(String message)?
-
Custom log output handler (defaults to print).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
String message) → void - Logs a debug message.
-
error(
String message, [Object? error, StackTrace? stackTrace]) → void - Logs an error message.
-
info(
String message) → void - Logs an informational message.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
warning(
String message) → void - Logs a warning message.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited