IntegralImage class
2D Integral Image (Summed Area Table) for $O(1)$ box query evaluations.
Constructors
- IntegralImage.fromImage(FaceImage image)
-
Creates an IntegralImage from a grayscale FaceImage.
factory
Properties
Methods
-
getSum(
int x1, int y1, int x2, int y2) → int -
Evaluates the total sum of pixel values within rectangle
x1, y1tox2, y2(inclusive) in $O(1)$ time. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited