TypedBufferUtils class abstract
Performance and safety utilities for working with TypedData buffers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
allocateFloat32(
int elements) → Float32List -
Allocates a contiguous Float32List of specified
elements. -
allocateUint8(
int bytes) → Uint8List -
Allocates a contiguous Uint8List of specified
bytes. -
copyUint8(
Uint8List source, Uint8List destination, {int sourceOffset = 0, int destinationOffset = 0, int? length}) → void - Fast memory copy from source Uint8List to target Uint8List.
-
rgbaToRgb(
Uint8List rgbaBuffer, int width, int height) → Uint8List - Converts an RGBA byte buffer to a 3-channel RGB buffer.
-
rgbToGrayscale(
Uint8List rgbBuffer, int width, int height) → Uint8List - Converts an RGB byte buffer to a 1-channel Grayscale buffer using standard luminance. (Luminance = 0.299 * R + 0.587 * G + 0.114 * B)